@@ -21,13 +21,14 @@ OCRD_TOOL = parse_json_string_with_comments(resource_string(__name__, 'ocrd-tool
 
 class DummyProcessor(Processor):
     """
-    Bare-bones processor that only copies mets:file from input group to output group.
+    Bare-bones processor creates PAGE-XML and optionally copies file from input group to output group
     """
 
     def process(self):
         LOG = getLogger('ocrd.dummy')
         assert_file_grp_cardinality(self.input_file_grp, 1)
         assert_file_grp_cardinality(self.output_file_grp, 1)
+        copy_files = self.parameter['copy_files']
         for input_file in self.input_files:
             input_file = self.workspace.download_file(input_file)
             file_id = make_file_id(input_file, self.output_file_grp)
@@ -36,8 +37,8 @@ class DummyProcessor(Processor):
             pcgts = page_from_file(self.workspace.download_file(input_file))
             pcgts.set_pcGtsId(file_id)
             self.add_metadata(pcgts)
-            LOG.info("cp %s %s # %s -> %s", input_file.url, local_filename, input_file.ID, file_id)
             if input_file.mimetype == MIMETYPE_PAGE:
+                LOG.info("cp %s %s # %s -> %s", input_file.url, local_filename, input_file.ID, file_id)
                 # Source file is PAGE-XML: Write out in-memory PcGtsType
                 self.workspace.add_file(
                     file_id=file_id,
@@ -47,24 +48,27 @@ class DummyProcessor(Processor):
                     local_filename=local_filename,
                     content=to_xml(pcgts).encode('utf-8'))
             else:
-                # Source file is not PAGE-XML: Copy byte-by-byte
-                with open(input_file.local_filename, 'rb') as f:
-                    content = f.read()
-                    self.workspace.add_file(
-                        file_id=file_id,
-                        file_grp=self.output_file_grp,
-                        page_id=input_file.pageId,
-                        mimetype=input_file.mimetype,
-                        local_filename=local_filename,
-                        content=content)
+                # Source file is not PAGE-XML: Copy byte-by-byte unless copy_files is False
+                if not copy_files:
+                    LOG.info("Not copying %s because it is not a PAGE-XML file and copy_files was false" % input_file.local_filename)
+                else:
+                    LOG.info("cp %s %s # %s -> %s", input_file.url, local_filename, input_file.ID, file_id)
+                    with open(input_file.local_filename, 'rb') as f:
+                        content = f.read()
+                        self.workspace.add_file(
+                            ID=file_id,
+                            file_grp=self.output_file_grp,
+                            pageId=input_file.pageId,
+                            mimetype=input_file.mimetype,
+                            local_filename=local_filename,
+                            content=content)
                 if input_file.mimetype.startswith('image/'):
                     # write out the PAGE-XML representation for this image
                     page_file_id = file_id + '_PAGE'
                     pcgts.set_pcGtsId(page_file_id)
-                    pcgts.get_Page().set_imageFilename(local_filename)
+                    pcgts.get_Page().set_imageFilename(local_filename if copy_files else input_file.local_filename)
                     page_filename = join(self.output_file_grp, file_id + '.xml')
-                    LOG.info("Add PAGE-XML %s generated for %s at %s",
-                             page_file_id, file_id, page_filename)
+                    LOG.info("Add PAGE-XML %s generated for %s at %s", page_file_id, file_id, page_filename)
                     self.workspace.add_file(
                         file_id=page_file_id,
                         file_grp=self.output_file_grp,
@@ -76,7 +80,7 @@ class DummyProcessor(Processor):
 
     def __init__(self, *args, **kwargs):
         kwargs['ocrd_tool'] = OCRD_TOOL
-        kwargs['version'] = '0.0.2'
+        kwargs['version'] = '0.0.3'
         super(DummyProcessor, self).__init__(*args, **kwargs)
 
 @click.command()
