@@ -1,16 +1,16 @@
 from pathlib import Path
 from os.path import join
-from json import loads
-from os import environ, listdir, getcwd, path
+from os import environ, listdir, getcwd, path, unlink
+from shutil import copytree, rmtree, copy
 from fnmatch import filter as apply_glob
-from shutil import copytree
 from datetime import datetime
 from tarfile import open as open_tarfile
 from urllib.parse import urlparse, unquote
-from subprocess import run, PIPE
+from zipfile import ZipFile
 
 import requests
 from yaml import safe_load, safe_dump
+import magic
 
 # https://github.com/OCR-D/core/issues/867
 # https://stackoverflow.com/questions/50900727/skip-converting-entities-while-loading-a-yaml-string-using-pyyaml
@@ -232,7 +232,7 @@ class OcrdResourceManager():
             return Path(name).stem
         raise ValueError("No such usage '%s'" % usage)
 
-    def _download_impl(self, url, filename, progress_cb=None):
+    def _download_impl(self, url, filename, progress_cb=None, size=None):
         log = getLogger('ocrd.resource_manager._download_impl')
         log.info("Downloading %s to %s" % (url, filename))
         with open(filename, 'wb') as f:
@@ -293,9 +293,15 @@ class OcrdResourceManager():
             name = Path(unquote(url_parsed.path)).name
         fpath = Path(destdir, name)
         is_url = url.startswith('https://') or url.startswith('http://')
-        if fpath.exists() and not overwrite:
-            log.info("%s to be %s to %s which already exists and overwrite is False" % (url, 'downloaded' if is_url else 'copied', fpath))
-            return fpath
+        if fpath.exists():
+            if not overwrite:
+                raise FileExistsError("%s %s already exists but --overwrite is not set" % ('Directory' if fpath.is_dir() else 'File', fpath))
+            if fpath.is_dir():
+                log.info("Removing existing target directory {fpath}")
+                rmtree(str(fpath))
+            else:
+                log.info("Removing existing target file {fpath}")
+                unlink(str(fpath))
         destdir.mkdir(parents=True, exist_ok=True)
         if resource_type in ('file', 'directory'):
             if is_url:
@@ -303,18 +309,27 @@ class OcrdResourceManager():
             else:
                 self._copy_impl(url, fpath, progress_cb)
         elif resource_type == 'archive':
+            archive_fname = 'download.tar.xx'
             with pushd_popd(tempdir=True) as tempdir:
                 if is_url:
-                    self._download_impl(url, 'download.tar.xx', progress_cb)
+                    self._download_impl(url, archive_fname, progress_cb)
                 else:
-                    self._copy_impl(url, 'download.tar.xx', progress_cb)
+                    self._copy_impl(url, archive_fname, progress_cb)
                 Path('out').mkdir()
                 with pushd_popd('out'):
-                    log.info("Extracting archive to %s/out" % tempdir)
-                    with open_tarfile('../download.tar.xx', 'r:*') as tar:
-                        tar.extractall()
+                    mimetype = magic.from_file(f'../{archive_fname}', mime=True)
+                    log.info("Extracting %s archive to %s/out" % (mimetype, tempdir))
+                    if mimetype == 'application/zip':
+                        with ZipFile(f'../{archive_fname}', 'r') as zipf:
+                            zipf.extractall()
+                    else:
+                        with open_tarfile(f'../{archive_fname}', 'r:*') as tar:
+                            tar.extractall()
                     log.info("Copying '%s' from archive to %s" % (path_in_archive, fpath))
-                    copytree(path_in_archive, str(fpath))
+                    if Path(path_in_archive).is_dir():
+                        copytree(path_in_archive, str(fpath))
+                    else:
+                        copy(path_in_archive, str(fpath))
         return fpath
 
     def _dedup_database(self, database=None, dedup_key='name'):
